home | help
GMX-CHI(1)			     GROMACS			      GMX-CHI(1)

NAME
     gmx-chi  -  Calculate everything you want to know about chi and other dihe-
     drals

SYNOPSIS
	gmx chi [-s [<.gro/.g96/...>]] [-f [<.xtc/.trr/...>]] [-ss [<.dat>]]
		[-o [<.xvg>]] [-p [<.pdb>]] [-jc [<.xvg>]] [-corr [<.xvg>]]
		[-g [<.log>]] [-ot [<.xvg>]] [-oh [<.xvg>]] [-rt [<.xvg>]]
		[-cp [<.xvg>]] [-b <time>] [-e <time>] [-dt <time>] [-[no]w]
		[-xvg <enum>] [-r0 <int>] [-rN <int>] [-[no]phi] [-[no]psi]
		[-[no]omega] [-[no]rama] [-[no]viol] [-[no]periodic]
		[-[no]all] [-[no]rad] [-[no]shift] [-binwidth <int>]
		[-core_rotamer <real>] [-maxchi <enum>] [-[no]normhisto]
		[-[no]ramomega] [-bfact <real>] [-[no]chi_prod] [-[no]HChi]
		[-bmax <real>] [-acflen <int>] [-[no]normalize] [-P <enum>]
		[-fitfn <enum>] [-beginfit <real>] [-endfit <real>]

DESCRIPTION
     gmx chi computes phi, psi, omega, and chi dihedrals for all your amino acid
     backbone and sidechains.  It can compute dihedral angle as  a  function  of
     time,  and  as  histogram	distributions.	 The distributions (histo-(dihe-
     dral)(RESIDUE).xvg) are cumulative over all residues of each type.

     If option -corr is given, the program will calculate dihedral  autocorrela-
     tion    functions.   The	function   used   is   C(t)   =   <cos(chi(tau))
     cos(chi(tau+t))>. The use of cosines rather  than	angles	themselves,  re-
     solves the problem of periodicity.  (Van der Spoel & Berendsen (1997), Bio-
     phys.  J. 72, 2032-2041).	Separate files for each dihedral of each residue
     (corr(dihedral)(RESIDUE)(nresnr).xvg) are output, as well as  a  file  con-
     taining the information for all residues (argument of -corr).

     With  option  -all,  the  angles  themselves as a function of time for each
     residue are  printed  to  separate  files	(dihedral)(RESIDUE)(nresnr).xvg.
     These can be in radians or degrees.

     A log file (argument -g) is also written. This contains

	* information about the number of residues of each type.

	* The NMR ^3J coupling constants from the Karplus equation.

	* a table for each residue of the number of transitions between rotamers
	  per nanosecond,  and the order parameter S^2 of each dihedral.

	* a table for each residue of the rotamer occupancy.

     All  rotamers  are  taken	as 3-fold, except for omega and chi dihedrals to
     planar groups (i.e. chi_2 of aromatics, Asp and Asn; chi_3 of Glu and  Gln;
     and  chi_4  of  Arg), which are 2-fold. "rotamer 0" means that the dihedral
     was not in the core region of each rotamer.  The width of the  core  region
     can be set with -core_rotamer

     The S^2 order parameters are also output to an .xvg file (argument -o ) and
     optionally  as  a	.pdb file with the S^2 values as B-factor (argument -p).
     The total number of rotamer transitions per timestep  (argument  -ot),  the
     number  of  transitions  per  rotamer (argument -rt), and the ^3J couplings
     (argument -jc), can also be written to .xvg files. Note that  the	analysis
     of  rotamer  transitions  assumes	that  the supplied trajectory frames are
     equally spaced in time.

     If  -chi_prod  is	set  (and  -maxchi  >  0),  cumulative	rotamers,   e.g.
     1+9(chi_1-1)+3(chi_2-1)+  (chi_3-1)  (if the residue has three 3-fold dihe-
     drals and -maxchi >= 3) are calculated. As before, if any dihedral  is  not
     in  the core region, the rotamer is taken to be 0. The occupancies of these
     cumulative rotamers (starting with rotamer 0) are written to the file  that
     is  the  argument	of  -cp,  and if the -all flag is given, the rotamers as
     functions of time are written to chiproduct(RESIDUE)(nresnr).xvg and  their
     occupancies to histo-chiproduct(RESIDUE)(nresnr).xvg.

     The  option  -r  generates  a  contour plot of the average omega angle as a
     function of the phi and psi angles, that is, in a Ramachandran plot the av-
     erage omega angle is plotted using color coding.

OPTIONS
     Options to specify input files:

     -s [<.gro/.g96/...>] (conf.gro)
	    Structure file: gro g96 pdb brk ent esp tpr

     -f [<.xtc/.trr/...>] (traj.xtc)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -ss [<.dat>] (ssdump.dat) (Optional)
	    Generic data file

     Options to specify output files:

     -o [<.xvg>] (order.xvg)
	    xvgr/xmgr file

     -p [<.pdb>] (order.pdb) (Optional)
	    Protein data bank file

     -jc [<.xvg>] (Jcoupling.xvg)
	    xvgr/xmgr file

     -corr [<.xvg>] (dihcorr.xvg) (Optional)
	    xvgr/xmgr file

     -g [<.log>] (chi.log)
	    Log file

     -ot [<.xvg>] (dihtrans.xvg) (Optional)
	    xvgr/xmgr file

     -oh [<.xvg>] (trhisto.xvg) (Optional)
	    xvgr/xmgr file

     -rt [<.xvg>] (restrans.xvg) (Optional)
	    xvgr/xmgr file

     -cp [<.xvg>] (chiprodhisto.xvg) (Optional)
	    xvgr/xmgr file

     Other options:

     -b <time> (0)
	    Time of first frame to read from trajectory (default unit ps)

     -e <time> (0)
	    Time of last frame to read from trajectory (default unit ps)

     -dt <time> (0)
	    Only use frame when t MOD dt = first time (default unit ps)

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -xvg <enum> (xmgrace)
	    xvg plot formatting: xmgrace, xmgr, none

     -r0 <int> (1)
	    starting residue

     -rN <int> (-1)
	    last residue

     -[no]phi (no)
	    Output for phi dihedral angles

     -[no]psi (no)
	    Output for psi dihedral angles

     -[no]omega (no)
	    Output for omega dihedrals (peptide bonds)

     -[no]rama (no)
	    Generate phi/psi and chi_1/chi_2 Ramachandran plots

     -[no]viol (no)
	    Write a file that gives 0 or 1 for violated Ramachandran angles

     -[no]periodic (yes)
	    Print dihedral angles modulo 360 degrees

     -[no]all (no)
	    Output separate files for every dihedral.

     -[no]rad (no)
	    in angle vs time files, use radians rather than degrees.

     -[no]shift (no)
	    Compute chemical shifts from phi/psi angles

     -binwidth <int> (1)
	    bin width for histograms (degrees)

     -core_rotamer <real> (0.5)
	    only the central -core_rotamer*(360/multiplicity)  belongs	to  each
	    rotamer (the rest is assigned to rotamer 0)

     -maxchi <enum> (0)
	    calculate first ndih chi dihedrals: 0, 1, 2, 3, 4, 5, 6

     -[no]normhisto (yes)
	    Normalize histograms

     -[no]ramomega (no)
	    compute  average  omega  as  a function of phi/psi and plot it in an
	    .xpm plot

     -bfact <real> (-1)
	    B-factor value for .pdb file for atoms with no  calculated	dihedral
	    order parameter

     -[no]chi_prod (no)
	    compute a single cumulative rotamer for each residue

     -[no]HChi (no)
	    Include dihedrals to sidechain hydrogens

     -bmax <real> (0)
	    Maximum  B-factor  on  any of the atoms that make up a dihedral, for
	    the dihedral angle to be considered in the	statistics.  Applies  to
	    database  work where a number of X-Ray structures is analyzed. -bmax
	    <= 0 means no limit.

     -acflen <int> (-1)
	    Length of the ACF, default is half the number of frames

     -[no]normalize (yes)
	    Normalize ACF

     -P <enum> (0)
	    Order of Legendre polynomial for ACF (0 indicates none): 0, 1, 2, 3

     -fitfn <enum> (none)
	    Fit function: none, exp, aexp, exp_exp, exp5, exp7, exp9

     -beginfit <real> (0)
	    Time where to begin the exponential fit of the correlation function

     -endfit <real> (-1)
	    Time where to end the exponential fit of the  correlation  function,
	    -1 is until the end

KNOWN ISSUES
     * N-terminal phi and C-terminal psi dihedrals are calculated in a non-stan-
       dard way, using H-N-CA-C for phi instead of C(-)-N-CA-C, and N-CA-C-O for
       psi  instead  of  N-CA-C-N(+).  This causes (usually small) discrepancies
       with the output of other tools like gmx rama.

     * Rotamers with multiplicity 2 are printed in chi.log as if they had multi-
       plicity 3, with the 3rd (g(+)) always having probability 0

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			      GMX-CHI(1)

home | help